package com.xinelu.manage.mapper.specialdiseasetriggercondition;

import com.xinelu.manage.domain.specialdiseasetriggercondition.SpecialDiseaseTriggerCondition;

import java.util.List;

/**
 * 触发条件关系Mapper接口
 *
 * @author xinelu
 * @date 2024-03-18
 */
public interface SpecialDiseaseTriggerConditionMapper {
    /**
     * 查询触发条件关系
     *
     * @param id 触发条件关系主键
     * @return 触发条件关系
     */
    SpecialDiseaseTriggerCondition selectSpecialDiseaseTriggerConditionById(Long id);

    /**
     * 查询触发条件关系列表
     *
     * @param specialDiseaseTriggerCondition 触发条件关系
     * @return 触发条件关系集合
     */
    List<SpecialDiseaseTriggerCondition> selectSpecialDiseaseTriggerConditionList(SpecialDiseaseTriggerCondition specialDiseaseTriggerCondition);

    /**
     * 新增触发条件关系
     *
     * @param specialDiseaseTriggerCondition 触发条件关系
     * @return 结果
     */
    int insertSpecialDiseaseTriggerCondition(SpecialDiseaseTriggerCondition specialDiseaseTriggerCondition);

    /**
     * 批量新增触发条件关系
     *
     * @param triggerConditionList 触发条件关系
     * @return 结果
     */
    int insertTriggerConditionList(List<SpecialDiseaseTriggerCondition> triggerConditionList);

    /**
     * 修改触发条件关系
     *
     * @param specialDiseaseTriggerCondition 触发条件关系
     * @return 结果
     */
    int updateSpecialDiseaseTriggerCondition(SpecialDiseaseTriggerCondition specialDiseaseTriggerCondition);

    /**
     * 删除触发条件关系
     *
     * @param id 触发条件关系主键
     * @return 结果
     */
    int deleteSpecialDiseaseTriggerConditionById(Long id);

    /**
     * 批量删除触发条件关系
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSpecialDiseaseTriggerConditionByIds(Long[] ids);

    /**
     * 删除触发条件关系
     *
     * @param routeId 触发条件关系主键
     * @return 结果
     */
    int deleteSpecialDiseaseTriggerConditionByRouteId(Long routeId);
}
